Struct rstack_self::Symbol[][src]

pub struct Symbol { /* fields omitted */ }

Information about a symbol.

Methods

impl Symbol
[src]

Returns the name of the symbol, if known.

Returns the file in which this symbol is defined, if known.

Returns the line at which the address which resolved to this symbol corresponds, if known.