Struct rstack_self::Symbol [−][src]
pub struct Symbol { /* fields omitted */ }Information about a symbol.
Methods
impl Symbol[src]
impl Symbolpub fn name(&self) -> Option<&str>[src]
pub fn name(&self) -> Option<&str>Returns the name of the symbol, if known.
pub fn file(&self) -> Option<&Path>[src]
pub fn file(&self) -> Option<&Path>Returns the file in which this symbol is defined, if known.
pub fn line(&self) -> Option<u32>[src]
pub fn line(&self) -> Option<u32>Returns the line at which the address which resolved to this symbol corresponds, if known.